@@ -1,22 +1,21 @@
 /*
  *  Hamlib Kenwood backend - TS450S description
- *  Copyright (c) 2000-2004 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *
- *	$Id: ts450s.c,v 1.30 2009-02-06 14:15:12 azummo Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -71,18 +70,25 @@ static const struct confparams ts450_ext_parms[] = {
 static int ts450_open(RIG *rig)
 {
 	int err;
+	int maxtries;
 
 	err = kenwood_open(rig);
 	if (err != RIG_OK)
 		return err;
 
+	maxtries = rig->state.rigport.retry;
+	/* no retry for this command that may be missing */
+	rig->state.rigport.retry = 0;
+
 	err = kenwood_simple_transaction(rig, "TO", 3);
 	if (err != RIG_OK) {
-        	rig_debug(RIG_DEBUG_TRACE, "%s: tone unit not detected\n", __func__);
+		rig_debug(RIG_DEBUG_VERBOSE, "%s: tone unit not detected\n", __func__);
 		rig->state.has_set_func &= ~RIG_FUNC_TONE;
 		rig->state.has_get_func &= ~RIG_FUNC_TONE;
 	}
 
+	rig->state.rigport.retry = maxtries;
+
 	return RIG_OK;
 }
 
@@ -105,7 +111,7 @@ const struct rig_caps ts450s_caps = {
 	.rig_model	= RIG_MODEL_TS450S,
 	.model_name	= "TS-450S",
 	.mfg_name	= "Kenwood",
-	.version	= BACKEND_VER,
+	.version	= BACKEND_VER ".1",
 	.copyright	= "LGPL",
 	.status		= RIG_STATUS_BETA,
 	.rig_type	= RIG_TYPE_TRANSCEIVER,
