@@ -2,21 +2,20 @@
  *  Hamlib KIT backend - Elektor DRM receiver description
  *  Copyright (c) 2004-2005 by Stephane Fillod
  *
- *	$Id: elektor304.c,v 1.7 2007-11-07 19:12:55 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -238,7 +237,7 @@ int elektor304_get_conf(RIG *rig, token_t token, char *val)
 /*
  * Introduce delay after changing the bit state
  * FIXME: This implementation may not work for very fast computers,
- * 		or smart compilers. However, nanosleep can have 
+ * 		or smart compilers. However, nanosleep can have
  * 		granularity > 10ms!
  */
 static int ad_delay(int m)
@@ -310,7 +309,7 @@ static int ad_write(hamlib_port_t *port, unsigned data)
 	ad_fsync(port, 0);	/* DTR 0 */
 
 	return RIG_OK;
-}	
+}
 
 
 int elektor304_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
@@ -339,7 +338,7 @@ int elektor304_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 	fhl = (frg>>16)& 0xff;
 	fhh = (frg>>24)& 0xff;
 
-	rig_debug(RIG_DEBUG_VERBOSE, "%s: %lu=[%02x.%02x.%02x.%02x]\n", 
+	rig_debug(RIG_DEBUG_VERBOSE, "%s: %lu=[%02x.%02x.%02x.%02x]\n",
 			__FUNCTION__,frg,fll,flh,fhl,fhh);
 
 	ad_write(port, 0xF800);  /* Reset */
@@ -347,7 +346,7 @@ int elektor304_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 	ad_write(port, 0x3000|fll);	/* 4 Bytes to FREQ0 */
 	ad_write(port, 0x2100|flh);
 	ad_write(port, 0x3200|fhl);
-	ad_write(port, 0x2300|fhh); 
+	ad_write(port, 0x2300|fhh);
 
 	ad_write(port, 0x8000);	/* Sync */
 	ad_write(port, 0xC000);	/* Reset end */
