@@ -4,6 +4,10 @@
 
 #if defined(WIN32) && !defined(HAVE_TERMIOS_H)
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h> /* usleep() */
+#endif
+
 #undef DEBUG
 #undef TRACE
 
@@ -24,9 +28,9 @@
 |   Copyright 1997-2006 by Trent Jarvi taj@www.linux.org.uk.
 |
 |   This library is free software; you can redistribute it and/or
-|   modify it under the terms of the GNU Library General Public
+|   modify it under the terms of the GNU Lesser General Public
 |   License as published by the Free Software Foundation; either
-|   version 2 of the License, or (at your option) any later version.
+|   version 2.1 of the License, or (at your option) any later version.
 |
 |   If you compile this program with cygwin32 tools this package falls
 |   under the GPL.  See COPYING.CYGNUS for details.
@@ -34,13 +38,13 @@
 |   This library is distributed in the hope that it will be useful,
 |   but WITHOUT ANY WARRANTY; without even the implied warranty of
 |   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-|   Library General Public License for more details.
+|   Lesser General Public License for more details.
 |
-|   You should have received a copy of the GNU Library General Public
-|   License along with this library; if not, write to the Free
-|   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|   You should have received a copy of the GNU Lesser General Public
+|   License along with this library; if not, write to the Free Software
+|   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 |
-| This file was taken from rxtx-2.1-7 and adaptated for Hamlib.
+| This file was taken from rxtx-2.1-7 and adapted for Hamlib.
 --------------------------------------------------------------------------*/
 #include <windows.h>
 #include <stdio.h>
@@ -88,13 +92,15 @@ struct termios_list
 };
 struct termios_list *first_tl = NULL;
 
+static struct termios_list *find_port( int );
+
 /*----------------------------------------------------------
 serial_test
 
-   accept: filename to test     
-   perform:     
+   accept: filename to test
+   perform:
    return:      1 on success 0 on failure
-   exceptions:  
+   exceptions:
    win32api:    CreateFile CloseHandle
    comments:    if the file opens it should be ok.
 ----------------------------------------------------------*/
@@ -122,7 +128,7 @@ int win32_serial_test( char * filename )
 	return(ret);
 }
 
-void termios_setflags( int fd, int termios_flags[] )
+static void termios_setflags( int fd, int termios_flags[] )
 {
 	struct termios_list *index = find_port( fd );
 	int i, result;
@@ -160,13 +166,14 @@ void termios_setflags( int fd, int termios_flags[] )
 	}
 }
 
+#if 0
 /*----------------------------------------------------------
 get_fd()
 
    accept:      filename
    perform:     find the file descriptor associated with the filename
    return:      fd
-   exceptions:  
+   exceptions:
    win32api:    None
    comments:    This is not currently called by anything
 ----------------------------------------------------------*/
@@ -223,9 +230,9 @@ char *get_filename( int fd )
 dump_termios_list()
 
    accept:      string to print out.
-   perform:     
-   return:      
-   exceptions:  
+   perform:
+   return:
+   exceptions:
    win32api:    None
    comments:    used only for debugging eg serial_close()
 ----------------------------------------------------------*/
@@ -248,19 +255,20 @@ void dump_termios_list( char *foo )
 	printf( "============== %s end  ===============\n", foo );
 #endif
 }
+#endif
 
 /*----------------------------------------------------------
 set_errno()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:    None
-   comments:   FIXME   
+   comments:   FIXME
 ----------------------------------------------------------*/
 
-void set_errno( int error )
+static void set_errno( int error )
 {
 	my_errno = error;
 }
@@ -269,15 +277,15 @@ void set_errno( int error )
 /*----------------------------------------------------------
 usleep()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:    Sleep()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-void usleep( unsigned long usec )
+static void usleep( unsigned long usec )
 {
 	Sleep( usec/1000 );
 }
@@ -286,15 +294,15 @@ void usleep( unsigned long usec )
 /*----------------------------------------------------------
 CBR_toB()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int CBR_to_B( int Baud )
+static int CBR_to_B( int Baud )
 {
 	ENTER( "CBR_to_B" );
 	switch ( Baud )
@@ -344,15 +352,15 @@ int CBR_to_B( int Baud )
 /*----------------------------------------------------------
 B_to_CBR()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:
    comments:      None
 ----------------------------------------------------------*/
 
-int B_to_CBR( int Baud )
+static int B_to_CBR( int Baud )
 {
 	int ret;
 	ENTER( "B_to_CBR" );
@@ -392,7 +400,7 @@ int B_to_CBR( int Baud )
 		case B3000000:	ret = CBR_3000000;	break;
 		case B3500000:	ret = CBR_3500000;	break;
 		case B4000000:	ret = CBR_4000000;	break;
-	
+
 		default:
 			fprintf( stderr, "B_to_CBR: invalid baudrate: %#o\n",
 				Baud );
@@ -406,15 +414,15 @@ int B_to_CBR( int Baud )
 /*----------------------------------------------------------
 bytesize_to_termios()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:      None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int bytesize_to_termios( int ByteSize )
+static int bytesize_to_termios( int ByteSize )
 {
 	ENTER( "bytesize_to_termios" );
 	switch ( ByteSize )
@@ -430,15 +438,15 @@ int bytesize_to_termios( int ByteSize )
 /*----------------------------------------------------------
 termios_to_bytesize()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int termios_to_bytesize( int cflag )
+static int termios_to_bytesize( int cflag )
 {
 	ENTER( "termios_to_bytesize" );
 	switch ( cflag & CSIZE )
@@ -455,15 +463,15 @@ int termios_to_bytesize( int cflag )
 /*----------------------------------------------------------
 get_dos_port()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-const char *get_dos_port( char const *name )
+static const char *get_dos_port( char const *name )
 {
 	ENTER( "get_dos_port" );
 	if ( !strcmp( name, "/dev/cua0" ) ) return( "COM1" );
@@ -478,15 +486,15 @@ const char *get_dos_port( char const *name )
 /*----------------------------------------------------------
 ClearErrors()
 
-   accept:       
+   accept:
    perform:      keep track of errors for the eventLoop() (SerialImp.c)
    return:       the return value of ClearCommError()
-   exceptions:  
+   exceptions:
    win32api:     ClearCommError()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int ClearErrors( struct termios_list *index, COMSTAT *Stat )
+static int ClearErrors( struct termios_list *index, COMSTAT *Stat )
 {
 	unsigned long ErrCode;
 	int ret;
@@ -545,18 +553,19 @@ int ClearErrors( struct termios_list *index, COMSTAT *Stat )
 	return( ret );
 }
 
+#if 0
 /*----------------------------------------------------------
 FillDCB()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     GetCommState(),  SetCommState(), SetCommTimeouts()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-BOOL FillDCB( DCB *dcb, unsigned long *hCommPort, COMMTIMEOUTS Timeout )
+static BOOL FillDCB( DCB *dcb, unsigned long *hCommPort, COMMTIMEOUTS Timeout )
 {
 
 	ENTER( "FillDCB" );
@@ -584,7 +593,7 @@ BOOL FillDCB( DCB *dcb, unsigned long *hCommPort, COMMTIMEOUTS Timeout )
 	dcb->XoffLim         = 0;
 	dcb->fParity = TRUE;
 	if ( EV_BREAK|EV_CTS|EV_DSR|EV_ERR|EV_RING|( EV_RLSD & EV_RXFLAG ) )
-		dcb->EvtChar = '\n'; 
+		dcb->EvtChar = '\n';
 	else dcb->EvtChar = '\0';
 	if ( !SetCommState( hCommPort, dcb ) )
 	{
@@ -601,16 +610,17 @@ BOOL FillDCB( DCB *dcb, unsigned long *hCommPort, COMMTIMEOUTS Timeout )
 	LEAVE( "FillDCB" );
 	return ( TRUE ) ;
 }
+#endif
 
 /*----------------------------------------------------------
 serial_close()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:      SetCommMask(), CloseHandle()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int win32_serial_close( int fd )
@@ -687,12 +697,12 @@ int win32_serial_close( int fd )
 /*----------------------------------------------------------
 cfmakeraw()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 void cfmakeraw( struct termios *s_termios )
@@ -708,17 +718,17 @@ void cfmakeraw( struct termios *s_termios )
 }
 
 /*----------------------------------------------------------
-init_termios()
+init_serial_struct()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-BOOL init_serial_struct( struct serial_struct *sstruct )
+static BOOL init_serial_struct( struct serial_struct *sstruct )
 {
 	ENTER( "init_serial_struct" );
 
@@ -771,15 +781,15 @@ BOOL init_serial_struct( struct serial_struct *sstruct )
 /*----------------------------------------------------------
 init_termios()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-BOOL init_termios(struct termios *ttyset )
+static BOOL init_termios(struct termios *ttyset )
 {
 	ENTER( "init_termios" );
 	if ( !ttyset )
@@ -799,7 +809,7 @@ BOOL init_termios(struct termios *ttyset )
 	ttyset->c_cc[VEOL] = '\r';	/* 11: */
 	ttyset->c_cc[VREPRINT] = 0x12;	/* 12: C-r */
 /*
-	ttyset->c_cc[VDISCARD] = 0x;	   13: IEXTEN only 
+	ttyset->c_cc[VDISCARD] = 0x;	   13: IEXTEN only
 */
 	ttyset->c_cc[VWERASE] = 0x17;	/* 14: C-w */
 	ttyset->c_cc[VLNEXT] = 0x16;	/* 15: C-w */
@@ -812,18 +822,18 @@ BOOL init_termios(struct termios *ttyset )
 /*----------------------------------------------------------
 port_opened()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int port_opened( const char *filename )
+static int port_opened( const char *filename )
 {
 	struct termios_list *index = first_tl;
-	
+
 	ENTER( "port_opened" );
 	if ( ! index )
 		return 0;
@@ -842,12 +852,12 @@ int port_opened( const char *filename )
 /*----------------------------------------------------------
 open_port()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:   CreateFile(), SetupComm(), CreateEvent()
-   comments:    
+   comments:
 	FILE_FLAG_OVERLAPPED allows one to break out the select()
 	so RXTXPort.close() does not hang.
 
@@ -859,7 +869,7 @@ open_port()
 	structure in Serial_select.
 ----------------------------------------------------------*/
 
-int open_port( struct termios_list *port )
+static int open_port( struct termios_list *port )
 {
 	ENTER( "open_port" );
 	port->hComm = CreateFile( port->filename,
@@ -900,7 +910,7 @@ int open_port( struct termios_list *port )
 
 	port->sol.hEvent = CreateEvent( NULL, TRUE, FALSE, NULL );
 
-	if ( !port->sol.hEvent )	
+	if ( !port->sol.hEvent )
 	{
 		YACK();
 		report( "Could not create select overlapped\n" );
@@ -908,7 +918,7 @@ int open_port( struct termios_list *port )
 	}
 	port->wol.hEvent = CreateEvent( NULL, TRUE, FALSE, NULL );
 
-	if ( !port->wol.hEvent )	
+	if ( !port->wol.hEvent )
 	{
 		YACK();
 		report( "Could not create write overlapped\n" );
@@ -931,10 +941,10 @@ termios_list()
 		 NULL if no matches are found.
    exceptions:   None
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-struct termios_list *find_port( int fd )
+static struct termios_list *find_port( int fd )
 {
 
 	char message[80];
@@ -965,15 +975,15 @@ fail:
 /*----------------------------------------------------------
 get_free_fd()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:       None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int get_free_fd()
+static int get_free_fd()
 {
 	int next, last;
 	struct termios_list *index = first_tl;
@@ -993,7 +1003,7 @@ int get_free_fd()
 		first_tl = index;
 		return ( 1 );
 	}
-	
+
 	last = index->fd;
 
 	while( index->next )
@@ -1002,7 +1012,7 @@ int get_free_fd()
 		if ( next !=  last + 1 )
 		{
 			return( last + 1 );
-			
+
 		}
 		index = index->next;
 		last = next;
@@ -1014,15 +1024,15 @@ int get_free_fd()
 /*----------------------------------------------------------
 add_port()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:      None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-struct termios_list *add_port( const char *filename )
+static struct termios_list *add_port( const char *filename )
 {
 	struct termios_list *index = first_tl;
 	struct termios_list *port;
@@ -1063,7 +1073,7 @@ struct termios_list *add_port( const char *filename )
 
 	port->fd = get_free_fd();
 
-	
+
 	if ( !first_tl )
 	{
 		port->prev = NULL;
@@ -1106,15 +1116,15 @@ fail:
 /*----------------------------------------------------------
 check_port_capabilities()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:      GetCommProperties(), GetCommState()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
-int check_port_capabilities( struct termios_list *index )
+static int check_port_capabilities( struct termios_list *index )
 {
 	COMMPROP cp;
 	DCB	dcb;
@@ -1160,12 +1170,12 @@ int check_port_capabilities( struct termios_list *index )
 /*----------------------------------------------------------
 serial_open()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:    None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int win32_serial_open( const char *filename, int flags, ... )
@@ -1185,7 +1195,7 @@ int win32_serial_open( const char *filename, int flags, ... )
 		report( "serial_open !index\n" );
 		return( -1 );
 	}
-	
+
 	index->interrupt = 0;
 	index->tx_happened = 0;
 	if ( open_port( index ) )
@@ -1233,14 +1243,14 @@ int win32_serial_open( const char *filename, int flags, ... )
 /*----------------------------------------------------------
 serial_write()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     WriteFile(), GetLastError(),
                  WaitForSingleObject(),  GetOverlappedResult(),
                  FlushFileBuffers(), Sleep()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int win32_serial_write( int fd, const char *Str, int length )
@@ -1266,9 +1276,9 @@ int win32_serial_write( int fd, const char *Str, int length )
 /*
 	index->event_flag &= ~EV_TXEMPTY;
 	SetCommMask( index->hComm, index->event_flag );
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 */
-	index->wol.Offset = index->wol.OffsetHigh = 0; 
+	index->wol.Offset = index->wol.OffsetHigh = 0;
 	ResetEvent( index->wol.hEvent );
 	if ( !WriteFile( index->hComm, Str, length, &nBytes, &index->wol ) )
 	{
@@ -1312,7 +1322,7 @@ end:
 	SetCommMask( index->hComm, index->event_flag );
 	/* ClearErrors( index, &Stat ); */
 	index->event_flag = old_flag;
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 	LEAVE( "serial_write" );
 	return nBytes;
 }
@@ -1320,14 +1330,14 @@ end:
 /*----------------------------------------------------------
 serial_read()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:      ReadFile(), GetLastError(), WaitForSingleObject()
                   GetOverLappedResult()
    comments:    If setting errno make sure not to use EWOULDBLOCK
-                In that case use EAGAIN.  See SerialImp.c:testRead() 
+                In that case use EAGAIN.  See SerialImp.c:testRead()
 ----------------------------------------------------------*/
 
 int win32_serial_read( int fd, void *vb, int size )
@@ -1335,13 +1345,13 @@ int win32_serial_read( int fd, void *vb, int size )
 	long start, now;
 	unsigned long nBytes = 0, total = 0, error;
 	/* unsigned long waiting = 0; */
-	int err, vmin; 
+	int err, vmin;
 	struct termios_list *index;
 	char message[80];
 	COMSTAT stat;
 	clock_t c;
 	unsigned char *dest = vb;
-	
+
 	start = GetTickCount();
 	ENTER( "serial_read" );
 
@@ -1415,7 +1425,7 @@ int win32_serial_read( int fd, void *vb, int size )
 		index->rol.Offset = index->rol.OffsetHigh = 0;
 		ResetEvent( index->rol.hEvent );
 
-		err = ReadFile( index->hComm, dest + total, size, &nBytes, &index->rol ); 
+		err = ReadFile( index->hComm, dest + total, size, &nBytes, &index->rol );
 #ifdef DEBUG_VERBOSE
 	/* warning Roy Rogers! */
 		sprintf(message, " ========== ReadFile = %i %s\n",
@@ -1424,7 +1434,7 @@ int win32_serial_read( int fd, void *vb, int size )
 #endif /* DEBUG_VERBOSE */
 		size -= nBytes;
 		total += nBytes;
-		
+
 		if ( !err )
 		{
 			switch ( GetLastError() )
@@ -1503,13 +1513,13 @@ int win32_serial_read( int fd, void *vb, int size )
 	long start, now;
 	unsigned long nBytes = 0, total = 0, error;
 	/* unsigned long waiting = 0; */
-	int err, vmin; 
+	int err, vmin;
 	struct termios_list *index;
 	char message[80];
 	COMSTAT Stat;
 	clock_t c;
 	unsigned char *dest = vb;
-	
+
 	start = GetTickCount();
 	ENTER( "serial_read" );
 
@@ -1589,7 +1599,7 @@ int win32_serial_read( int fd, void *vb, int size )
 		index->rol.Offset = index->rol.OffsetHigh = 0;
 		ResetEvent( index->rol.hEvent );
 
-		err = ReadFile( index->hComm, dest + total, size, &nBytes, &index->rol ); 
+		err = ReadFile( index->hComm, dest + total, size, &nBytes, &index->rol );
 #ifdef DEBUG_VERBOSE
 	/* warning Roy Rogers! */
 		sprintf(message, " ========== ReadFile = %i %s\n",
@@ -1598,7 +1608,7 @@ int win32_serial_read( int fd, void *vb, int size )
 #endif /* DEBUG_VERBOSE */
 		size -= nBytes;
 		total += nBytes;
-		
+
 		if ( !err )
 		{
 			switch ( GetLastError() )
@@ -1681,12 +1691,12 @@ int win32_serial_read( int fd, void *vb, int size )
 /*----------------------------------------------------------
 cfsetospeed()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int cfsetospeed( struct termios *s_termios, speed_t speed )
@@ -1706,7 +1716,7 @@ int cfsetospeed( struct termios *s_termios, speed_t speed )
 	{
 		s_termios->c_cflag |= speed;
 	}
-	else 
+	else
 	{
 		/* PC blows up with speed 0 handled in Java */
 		s_termios->c_cflag |= B9600;
@@ -1718,12 +1728,12 @@ int cfsetospeed( struct termios *s_termios, speed_t speed )
 /*----------------------------------------------------------
 cfsetispeed()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int cfsetispeed( struct termios *s_termios, speed_t speed )
@@ -1734,12 +1744,12 @@ int cfsetispeed( struct termios *s_termios, speed_t speed )
 /*----------------------------------------------------------
 cfsetspeed()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int cfsetspeed( struct termios *s_termios, speed_t speed )
@@ -1750,12 +1760,12 @@ int cfsetspeed( struct termios *s_termios, speed_t speed )
 /*----------------------------------------------------------
 cfgetospeed()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 speed_t cfgetospeed( struct termios *s_termios )
@@ -1767,12 +1777,12 @@ speed_t cfgetospeed( struct termios *s_termios )
 /*----------------------------------------------------------
 cfgetispeed()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 speed_t cfgetispeed( struct termios *s_termios )
@@ -1784,12 +1794,12 @@ speed_t cfgetispeed( struct termios *s_termios )
 /*----------------------------------------------------------
 serial_struct_to_DCB()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 int serial_struct_to_DCB( struct serial_struct *sstruct, DCB *dcb )
 {
@@ -1803,14 +1813,14 @@ int serial_struct_to_DCB( struct serial_struct *sstruct, DCB *dcb )
 /*----------------------------------------------------------
 termios_to_DCB()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
-int termios_to_DCB( struct termios *s_termios, DCB *dcb )
+static int termios_to_DCB( struct termios *s_termios, DCB *dcb )
 {
 	ENTER( "termios_to_DCB" );
 	s_termios->c_ispeed = s_termios->c_ospeed = s_termios->c_cflag & CBAUD;
@@ -1819,7 +1829,7 @@ int termios_to_DCB( struct termios *s_termios, DCB *dcb )
 
 	if ( s_termios->c_cflag & PARENB )
 	{
-		if ( s_termios->c_cflag & PARODD 
+		if ( s_termios->c_cflag & PARODD
 			&& s_termios->c_cflag & CMSPAR )
 		{
 			dcb->Parity = MARKPARITY;
@@ -1840,7 +1850,7 @@ int termios_to_DCB( struct termios *s_termios, DCB *dcb )
 	else
 	{
 		dcb->Parity = NOPARITY;
-	}	
+	}
 
 	if ( s_termios->c_cflag & CSTOPB ) dcb->StopBits = TWOSTOPBITS;
 		else dcb->StopBits = ONESTOPBIT;
@@ -1863,12 +1873,12 @@ int termios_to_DCB( struct termios *s_termios, DCB *dcb )
 /*----------------------------------------------------------
 DCB_to_serial_struct()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 int DCB_to_serial_struct( DCB *dcb, struct serial_struct *sstruct  )
 {
@@ -1877,14 +1887,14 @@ int DCB_to_serial_struct( DCB *dcb, struct serial_struct *sstruct  )
 /*----------------------------------------------------------
 DCB_to_termios()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
-void DCB_to_termios( DCB *dcb, struct termios *s_termios )
+static void DCB_to_termios( DCB *dcb, struct termios *s_termios )
 {
 	ENTER( "DCB_to_termios" );
 	s_termios->c_ispeed = CBR_to_B( dcb->BaudRate );
@@ -1896,14 +1906,14 @@ void DCB_to_termios( DCB *dcb, struct termios *s_termios )
 /*----------------------------------------------------------
 show_DCB()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 ----------------------------------------------------------*/
-void show_DCB( myDCB )
+static void show_DCB( DCB myDCB )
 {
 
 #ifdef DEBUG_HOSED
@@ -2018,12 +2028,12 @@ void show_DCB( myDCB )
 /*----------------------------------------------------------
 tcgetattr()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:    GetCommState(), GetCommTimeouts()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int tcgetattr( int fd, struct termios *s_termios )
@@ -2102,11 +2112,11 @@ int tcgetattr( int fd, struct termios *s_termios )
 	/* CSTOPB two stop bits ( otherwise one) */
 	if ( myDCB.StopBits == TWOSTOPBITS )
 	{
-		s_termios->c_cflag |= CSTOPB;	
+		s_termios->c_cflag |= CSTOPB;
 	}
 	if ( myDCB.StopBits == ONESTOPBIT )
 	{
-		s_termios->c_cflag &= ~CSTOPB;	
+		s_termios->c_cflag &= ~CSTOPB;
 	}
 
 
@@ -2236,13 +2246,13 @@ int tcgetattr( int fd, struct termios *s_termios )
 /*----------------------------------------------------------
 tcsetattr()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     GetCommState(), GetCommTimeouts(), SetCommState(),
                  SetCommTimeouts()
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 int tcsetattr( int fd, int when, struct termios *s_termios )
 {
@@ -2304,8 +2314,8 @@ int tcsetattr( int fd, int when, struct termios *s_termios )
 */
 	/* not in win95?
 	   Some years later...
-	   eww..  FIXME This is used for changing the Parity 
-	   error character 
+	   eww..  FIXME This is used for changing the Parity
+	   error character
 
 	   I think this code is hosed.  See VEOF below
 
@@ -2428,12 +2438,12 @@ int tcsetattr( int fd, int when, struct termios *s_termios )
 /*----------------------------------------------------------
 tcsendbreak()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:    
+   comments:
 		break for duration*0.25 seconds or
 		0.25 seconds if duration = 0.
 ----------------------------------------------------------*/
@@ -2473,7 +2483,7 @@ tcdrain()
    return:       0 on success, -1 otherwise
    exceptions:   None
    win32api:     FlushFileBuffers
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int tcdrain ( int fd )
@@ -2494,7 +2504,7 @@ int tcdrain ( int fd )
 /*
 	index->event_flag &= ~EV_TXEMPTY;
 	SetCommMask( index->hComm, index->event_flag );
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 */
 	if ( !FlushFileBuffers( index->hComm ) )
 	{
@@ -2511,7 +2521,7 @@ int tcdrain ( int fd )
 		report( message );
 		if( GetLastError() == 0 )
 		{
-			set_errno( 0 ); 
+			set_errno( 0 );
 			return(0);
 		}
 		set_errno( EAGAIN );
@@ -2529,7 +2539,7 @@ int tcdrain ( int fd )
 	SetCommMask( index->hComm, index->event_flag );
 	index->event_flag = old_flag;
 /*
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 */
 	return 0;
 }
@@ -2537,7 +2547,7 @@ int tcdrain ( int fd )
 /*----------------------------------------------------------
 tcflush()
 
-   accept:       file descriptor, queue_selector 
+   accept:       file descriptor, queue_selector
    perform:      discard data not transmitted or read
 		 TCIFLUSH:  flush data not read
 		 TCOFLUSH:  flush data not transmitted
@@ -2545,7 +2555,7 @@ tcflush()
    return:       0 on success, -1 on error
    exceptions:   none
    win32api:     PurgeComm
-   comments:    
+   comments:
 ----------------------------------------------------------*/
 
 int tcflush( int fd, int queue_selector )
@@ -2553,6 +2563,8 @@ int tcflush( int fd, int queue_selector )
 	struct termios_list *index;
 	int old_flag;
 
+	ENTER( "tcflush" );
+
 	index = find_port( fd );
 	if( !index)
 	{
@@ -2564,16 +2576,10 @@ int tcflush( int fd, int queue_selector )
 /*
 	index->event_flag &= ~EV_TXEMPTY;
 	SetCommMask( index->hComm, index->event_flag );
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 */
-	ENTER( "tcflush" );
-	if ( !index )
-	{
-		LEAVE( "tcflush" );
-		return -1;
-	}
 
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 	switch( queue_selector )
 	{
 		case TCIFLUSH:
@@ -2609,7 +2615,7 @@ int tcflush( int fd, int queue_selector )
 	index->event_flag |= EV_TXEMPTY;
 	SetCommMask( index->hComm, index->event_flag );
 	index->event_flag = old_flag;
-	index->tx_happened = 1; 
+	index->tx_happened = 1;
 	LEAVE( "tcflush" );
 	return( 0 );
 
@@ -2629,12 +2635,12 @@ fail:
 /*----------------------------------------------------------
 tcflow()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     None
-   comments:   FIXME 
+   comments:   FIXME
 ----------------------------------------------------------*/
 
 int tcflow( int fd, int action )
@@ -2658,11 +2664,11 @@ int tcflow( int fd, int action )
 /*----------------------------------------------------------
 fstat()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
-   win32api:    
+   accept:
+   perform:
+   return:
+   exceptions:
+   win32api:
    comments:  this is just to keep the eventLoop happy.
 ----------------------------------------------------------*/
 
@@ -2676,10 +2682,10 @@ int fstat( int fd, ... )
 /*----------------------------------------------------------
 ioctl()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:     GetCommError(), GetCommModemStatus, EscapeCommFunction()
    comments:  FIXME
 	the DCB struct is:
@@ -2730,7 +2736,7 @@ int win32_serial_ioctl( int fd, int request, ... )
 	}
 
 	va_start( ap, request );
-	
+
 	ret = ClearErrors( index, &Stat );
 	if (ret == 0)
 	{
@@ -2739,7 +2745,7 @@ int win32_serial_ioctl( int fd, int request, ... )
 		report( "ClearError Failed! ernno EBADFD" );
 		arg = va_arg( ap, int * );
 		va_end( ap );
-		return -1;		
+		return -1;
 	}
 	switch( request )
 	{
@@ -2763,7 +2769,7 @@ int win32_serial_ioctl( int fd, int request, ... )
 		case TIOCCBRK:
 		case TIOCSBRK:
 			arg = va_arg( ap, int * );
-			if ( EscapeCommFunction( index->hComm, 
+			if ( EscapeCommFunction( index->hComm,
 				( request == TIOCSBRK ) ? SETBREAK :
 				CLRBREAK ) )
 				report( "EscapeCommFunction: True\n" );
@@ -2864,7 +2870,7 @@ int win32_serial_ioctl( int fd, int request, ... )
 			{
 				index->MSR &= ~TIOCM_DTR;
 			}
-			if ( EscapeCommFunction( index->hComm, 
+			if ( EscapeCommFunction( index->hComm,
 				( *arg & TIOCM_DTR ) ? SETDTR :
 				CLRDTR ) )
 				report( "EscapeCommFunction: True\n" );
@@ -3108,15 +3114,15 @@ int win32_serial_ioctl( int fd, int request, ... )
 /*----------------------------------------------------------
 fcntl()
 
-   accept:      
-   perform:     
-   return:      
-   exceptions:  
+   accept:
+   perform:
+   return:
+   exceptions:
    win32api:    None
    comments:    FIXME
 ----------------------------------------------------------*/
 
-int fcntl( int fd, int command, ... )
+int win32_serial_fcntl( int fd, int command, ... )
 {
 	int arg, ret = 0;
 	va_list ap;
@@ -3161,17 +3167,18 @@ int fcntl( int fd, int command, ... )
 	return ret;
 }
 
+#if 0
 /*----------------------------------------------------------
 termios_interrupt_event_loop()
 
-   accept:      
-   perform:     
+   accept:
+   perform:
    return:	let Serial_select break out so the thread can die
-   exceptions:  
-   win32api:    
-   comments:    
+   exceptions:
+   win32api:
+   comments:
 ----------------------------------------------------------*/
-void termios_interrupt_event_loop( int fd, int flag )
+static void termios_interrupt_event_loop( int fd, int flag )
 {
 	struct termios_list * index = find_port( fd );
 	if ( !index )
@@ -3184,21 +3191,22 @@ void termios_interrupt_event_loop( int fd, int flag )
 	 TRENT SetCommMask( index->hComm, index->event_flag );
 	usleep(2000);
 	tcdrain( index->fd );
-	SetEvent( index->sol.hEvent ); 
+	SetEvent( index->sol.hEvent );
 */
 	index->interrupt = flag;
 	return;
 }
+#endif
 
 /*----------------------------------------------------------
 Serial_select()
 
-   accept:      
-   perform:     
+   accept:
+   perform:
    return:      number of fd's changed on success or -1 on error.
-   exceptions:  
-   win32api:    SetCommMask(), GetCommEvent(), WaitSingleObject() 
-   comments:    
+   exceptions:
+   win32api:    SetCommMask(), GetCommEvent(), WaitSingleObject()
+   comments:
 ----------------------------------------------------------*/
 #ifndef __LCC__
 int  win32_serial_select( int  n,  fd_set  *readfds,  fd_set  *writefds,
@@ -3240,7 +3248,7 @@ int  win32_serial_select( int  n,  fd_set  *readfds,  fd_set  *writefds,
 		/* still setting up the port? hold off for a Sec so
 		   things can fire up
 
-		   this does happen.  loops ~twice on a 350 Mzh with 
+		   this does happen.  loops ~twice on a 350 Mzh with
 		   usleep(1000000)
 		*/
 		usleep(10000);
@@ -3314,7 +3322,7 @@ int  win32_serial_select( int  n,  fd_set  *readfds,  fd_set  *writefds,
 			case WAIT_ABANDONED:
 			default:
 				goto fail;
-			
+
 		}
 	}
 end:
@@ -3364,7 +3372,7 @@ int  win32_serial_select( int  n,  fd_set  *readfds,  fd_set  *writefds,
 		usleep(1000);
 		return -1;
 	}
-	
+
 	while ( wait == WAIT_TIMEOUT && index->sol.hEvent )
 	{
 		if( index->interrupt == 1 )
@@ -3422,7 +3430,7 @@ int  win32_serial_select( int  n,  fd_set  *readfds,  fd_set  *writefds,
 			case WAIT_TIMEOUT:
 			default:
 				return(1); /* WaitFor error */
-			
+
 		}
 	}
 end:
@@ -3441,11 +3449,12 @@ fail:
 	LEAVE( "serial_select" );
 	return( 1 );
 #endif /* asdf */
-	
+
 }
 #endif /* asdf */
 #endif /* __LCC__ */
 
+#if 0
 /*----------------------------------------------------------
 termiosSetParityError()
 
@@ -3457,7 +3466,7 @@ termiosSetParityError()
    comments:    No idea how to do this in Unix  (handle in read?)
 ----------------------------------------------------------*/
 
-int termiosGetParityErrorChar( int fd )
+static int termiosGetParityErrorChar( int fd )
 {
 	struct termios_list *index;
 	DCB	dcb;
@@ -3485,12 +3494,12 @@ termiosSetParityError()
    comments:    No idea how to do this in Unix  (handle in read?)
 ----------------------------------------------------------*/
 
-void termiosSetParityError( int fd, char value )
+static void termiosSetParityError( int fd, char value )
 {
 	DCB	dcb;
 	struct termios_list *index;
 
-	ENTER( "termiosGetParityErrorChar" );
+	ENTER( "termiosSetParityErrorChar" );
 	index = find_port( fd );
 	if ( !index )
 	{
@@ -3500,8 +3509,10 @@ void termiosSetParityError( int fd, char value )
 	GetCommState( index->hComm, &dcb );
 	dcb.ErrorChar = value;
 	SetCommState( index->hComm, &dcb );
-	LEAVE( "termiosGetParityErrorChar" );
+	LEAVE( "termiosSetParityErrorChar" );
 }
+#endif
+
 /*----------------------- END OF LIBRARY -----------------*/
 
 #endif	/* WIN32 */
