@@ -2,21 +2,20 @@
  *  Hamlib Interface - provides registering for dynamically loadable backends.
  *  Copyright (c) 2000-2005 by Stephane Fillod
  *
- *	$Id: register.c,v 1.24 2006-10-15 00:27:51 aa6e Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -142,7 +141,7 @@ static int rig_lookup_backend(rig_model_t rig_model)
 	int i;
 
 	for (i=0; i<RIG_BACKEND_MAX && rig_backend_list[i].be_name; i++) {
-		if (RIG_BACKEND_NUM(rig_model) == 
+		if (RIG_BACKEND_NUM(rig_model) ==
 					rig_backend_list[i].be_num)
 			return i;
 	}
@@ -161,7 +160,7 @@ int HAMLIB_API rig_check_backend(rig_model_t rig_model)
 	const struct rig_caps *caps;
 	int be_idx;
 	int retval;
-	
+
 	/* already loaded ? */
 	caps = rig_get_caps(rig_model);
 	if (caps)
@@ -174,7 +173,7 @@ int HAMLIB_API rig_check_backend(rig_model_t rig_model)
 	 */
 	if (be_idx == -1) {
 		rig_debug(RIG_DEBUG_VERBOSE, "rig_check_backend: unsupported "
-					"backend %d for model %d\n", 
+					"backend %d for model %d\n",
 					RIG_BACKEND_NUM(rig_model), rig_model);
 		return -RIG_ENAVAIL;
 	}
@@ -351,7 +350,7 @@ int HAMLIB_API rig_load_backend(const char *be_name)
 	be_handle = lt_dlopenext (libname);
 
 	/*
-	 * external module not found? try dlopenself for backends 
+	 * external module not found? try dlopenself for backends
 	 * compiled in static
 	 */
 	if (!be_handle || rig_check_backend_version(be_handle, be_name, &be_init) != RIG_OK) {
@@ -375,7 +374,7 @@ int HAMLIB_API rig_load_backend(const char *be_name)
 	for (i=0; i<RIG_BACKEND_MAX && rig_backend_list[i].be_name; i++) {
 		if (!strncmp(be_name, rig_backend_list[i].be_name, 64)) {
     			snprintf(probefname, MAXFUNCNAMELEN, "probeallrigs%d_%s", ABI_VERSION, be_name);
-    			rig_backend_list[i].be_probe_all = 
+    			rig_backend_list[i].be_probe_all =
 				(rig_model_t (*)(hamlib_port_t*, rig_probe_func_t, rig_ptr_t))
 						lt_dlsym (be_handle, probefname);
 				break;
