@@ -2,21 +2,20 @@
  *  Hamlib Interface - provides registering for dynamically loadable backends.
  *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: rot_reg.c,v 1.10 2006-10-15 00:27:52 aa6e Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -144,7 +143,7 @@ static int rot_lookup_backend(rot_model_t rot_model)
 	int i;
 
 	for (i=0; i<ROT_BACKEND_MAX && rot_backend_list[i].be_name; i++) {
-		if (ROT_BACKEND_NUM(rot_model) == 
+		if (ROT_BACKEND_NUM(rot_model) ==
 				rot_backend_list[i].be_num)
 			return i;
 	}
@@ -162,7 +161,7 @@ int HAMLIB_API rot_check_backend(rot_model_t rot_model)
 	const struct rot_caps *caps;
 	int be_idx;
 	int retval;
-	
+
 	/* already loaded ? */
 	caps = rot_get_caps(rot_model);
 	if (caps)
@@ -175,11 +174,11 @@ int HAMLIB_API rot_check_backend(rot_model_t rot_model)
 	 */
 	if (be_idx == -1) {
 		rot_debug(RIG_DEBUG_VERBOSE, "rot_check_backend: unsupported "
-					"backend %d for model %d\n", 
+					"backend %d for model %d\n",
 					ROT_BACKEND_NUM(rot_model), rot_model);
 		return -RIG_ENAVAIL;
 	}
-			
+
 	retval = rot_load_backend(rot_backend_list[be_idx].be_name);
 
 	return retval;
@@ -302,7 +301,7 @@ int HAMLIB_API rot_load_backend(const char *be_name)
 	be_handle = lt_dlopenext (libname);
 
 	/*
-	 * external module not found? try dlopenself for backends 
+	 * external module not found? try dlopenself for backends
 	 * compiled in static
 	 */
 	if (!be_handle) {
