@@ -9,22 +9,19 @@
  * "CAT" interface box (FIF-232C) or similar.
  *
  *
- * $Id: ft757gx.c,v 1.13 2009-02-20 15:21:52 fillods Exp $
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
+ *   This library is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ *   You should have received a copy of the GNU Lesser General Public
+ *   License along with this library; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -79,7 +76,7 @@ const struct rig_caps ft757gx_caps = {
     .rig_model =        RIG_MODEL_FT757,
     .model_name =       "FT-757GX",
     .mfg_name =         "Yaesu",
-    .version =          "0.4",
+    .version =          "0.4.1",
     .copyright =        "LGPL",
     .status =           RIG_STATUS_BETA,
     .rig_type =         RIG_TYPE_MOBILE,
@@ -289,7 +286,7 @@ const struct rig_caps ft757gx2_caps = {
 
 
 /*
- * _init 
+ * _init
  *
  */
 
@@ -326,9 +323,6 @@ int ft757_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called.\n", __func__);
 
-    if (!rig)
-        return -RIG_EINVAL;
-  
     if (rig->state.priv)
         free(rig->state.priv);
     rig->state.priv = NULL;
@@ -338,7 +332,7 @@ int ft757_cleanup(RIG *rig)
 
 /*
  * ft757_open  routine
- * 
+ *
  */
 
 int ft757_open(RIG *rig)
@@ -348,9 +342,6 @@ int ft757_open(RIG *rig)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called.\n", __func__);
 
-    if (!rig)
-        return -RIG_EINVAL;
-
     /* FT757GX has a write-only serial port: don't try to read status data */
     if (rig->caps->rig_model == RIG_MODEL_FT757) {
       memset(priv->update_data, 0, FT757GX_STATUS_UPDATE_DATA_LENGTH);
